==> haskell-free-5.1.10-76-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 free
version:              5.1.10
visibility:           public
id:                   free-5.1.10-GOblXT8Z2deK2DPOVW8Wt0
key:                  free-5.1.10-GOblXT8Z2deK2DPOVW8Wt0
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/free/
synopsis:             Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.

    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.

    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.

    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>

category:             Control, Monads
abi:                  26e32e62f042109d59eefd58ad9c81cb
exposed:              True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter

hidden-modules:       Data.Functor.Classes.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/free-5.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/free-5.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-free
hs-libraries:         HSfree-5.1.10-GOblXT8Z2deK2DPOVW8Wt0
includes:             free-common.h
depends:
    base-4.16.4.0 comonad-5.0.8-ApzGC3RbXnnLePVoN4sF11
    containers-0.6.5.1 distributive-0.6.2.1-KvikcorRvGbIZwiFjHIAfQ
    exceptions-0.10.4 indexed-traversable-0.1.3-FGAp4VsezN7HyqjQRvrfWc
    mtl-2.2.2 profunctors-5.6.2-FWe4PQU8eE3GeDqm3R4ckm
    semigroupoids-5.3.7-3HMcZlsRlqoKaeVPumQFHg
    template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2
    transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN

haddock-interfaces:   /usr/share/doc/haskell-free/html/free.haddock
haddock-html:         /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-5.2-37.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 free
version:              5.2
visibility:           public
id:                   free-5.2-BmSPX9aY7BM8SWgWJCvikU
key:                  free-5.2-BmSPX9aY7BM8SWgWJCvikU
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/free/
synopsis:             Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.

    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.

    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.

    More information on free monads, including examples, can be found in the
    following blog posts:
    <https://ekmett.github.io/reader/2008/monads-for-free/>
    <https://ekmett.github.io/reader/2011/free-monads-for-less/>

category:             Control, Monads
abi:                  954b0a698ebfd116fd284b20bb1dcffd
exposed:              True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter

import-dirs:          /usr/lib/ghc-9.4.8/site-local/free-5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/free-5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/free-5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-free
hs-libraries:         HSfree-5.2-BmSPX9aY7BM8SWgWJCvikU
depends:
    base-4.17.2.1 comonad-5.0.9-LM1ahowzmtC8eowhfQckZC containers-0.6.7
    distributive-0.6.2.1-FYzr9HBqNWBC7NPu6PBGmX exceptions-0.10.5
    indexed-traversable-0.1.4-KBBDB9eVvy75srrGe861vR mtl-2.2.2
    profunctors-5.6.2-2HJkXKlrQqeIGAKueBx4y0
    semigroupoids-6.0.1-A8MJM4jzMu8HCltRHXZtTa
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    transformers-base-0.4.6-Gpx2WMc051hBRdn2HnKilA

haddock-interfaces:   /usr/share/doc/haskell-free/html/free.haddock
haddock-html:         /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
